@@ -28,8 +28,6 @@
  * \file gsb_file_config.c
  * save and load the config file
  */
-#ifdef USE_CONFIG_FILE
-
 #include "include.h"
 #include <errno.h>
 #include <glib/gstdio.h>
@@ -89,7 +87,8 @@ static void grisbi_conf_clean_config (GrisbiAppConf *a_conf)
 	a_conf->sauvegarde_fermeture = TRUE;
 
 	/* priv->settings_display */
-    a_conf->display_toolbar = GSB_BUTTON_BOTH;				/* "Text + Icons" */
+	a_conf->display_help = 0;								/* Html */
+    a_conf->display_toolbar = GTK_TOOLBAR_BOTH;				/* "Text + Icons" */
 	a_conf->display_window_title = 0;						/* "Entity name" */
 	a_conf->formulaire_toujours_affiche = TRUE;
 	a_conf->group_partial_balance_under_accounts = TRUE;
@@ -167,11 +166,11 @@ static void grisbi_conf_clean_config (GrisbiAppConf *a_conf)
     a_conf->panel_width = PANEL_MIN_WIDTH;
 
 	/* settings_prefs */
-    a_conf->prefs_archives_sort_order = FALSE;
-    a_conf->prefs_fyear_sort_order = FALSE;
-    a_conf->prefs_height = 600;
-	a_conf->prefs_panel_width = 360;
-    a_conf->prefs_width = 1050;
+    a_conf->prefs_archives_sort_order = GTK_SORT_ASCENDING;
+    a_conf->prefs_fyear_sort_order = GTK_SORT_ASCENDING;
+	a_conf->prefs_height = PREFS_WIN_MIN_HEIGHT;
+	a_conf->prefs_panel_width = PREFS_PANED_MIN_WIDTH;
+	a_conf->prefs_width = PREFS_WIN_MIN_WIDTH_HIGH;
 
 	/* settings_scheduled */
     a_conf->balances_with_scheduled = TRUE;
@@ -236,6 +235,7 @@ gboolean grisbi_conf_load_app_config (void)
 								      NULL);
     if (tmp_path == NULL || strlen (tmp_path) == 0)
     {
+		g_free(tmp_path);
         tmp_path = g_strdup (gsb_dirs_get_user_data_dir ());
     }
     gsb_file_set_backup_path (tmp_path);
@@ -275,16 +275,26 @@ gboolean grisbi_conf_load_app_config (void)
 														  NULL);
 
 	/* priv->settings_display */
+	tmp_str = g_key_file_get_string (config,
+								     "Display",
+								     "display-help",
+								     NULL);
+    if (g_strcmp0 (tmp_str, "Html") == 0)
+		a_conf->display_help = 0;
+	else
+		a_conf->display_help = 1;
+    g_free (tmp_str);
+
 	tmp_str = g_key_file_get_string (config,
 								     "Display",
 								     "display-toolbar",
 								     NULL);
     if (g_strcmp0 (tmp_str, "Text") == 0)
-        a_conf->display_toolbar = GSB_BUTTON_TEXT;
+        a_conf->display_toolbar = GTK_TOOLBAR_TEXT;
     else if (g_strcmp0 (tmp_str, "Icons") == 0)
-        a_conf->display_toolbar = GSB_BUTTON_ICON;
+        a_conf->display_toolbar = GTK_TOOLBAR_ICONS;
     else
-        a_conf->display_toolbar = GSB_BUTTON_BOTH;
+        a_conf->display_toolbar = GTK_TOOLBAR_BOTH;
     g_free (tmp_str);
 
 	tmp_str = g_key_file_get_string (config,
@@ -352,25 +362,25 @@ gboolean grisbi_conf_load_app_config (void)
 																			  "File",
 																			  "max-transactions-before-warn-archival",
 																			  NULL);
+	if (a_conf->max_non_archived_transactions_for_check < 3000)
+		a_conf->max_non_archived_transactions_for_check = 3000;
+
+	/* set list of files */
 	recent_array = g_key_file_get_string_list (config,
 											   "File",
 											   "names-last-files",
-                        			 		   NULL,
+											   NULL,
 											   NULL);
 	if (recent_array)
 	{
-        a_conf->nb_derniers_fichiers_ouverts = g_strv_length (recent_array);
-        if (a_conf->nb_derniers_fichiers_ouverts > 0)
-        {
-			if (a_conf->nb_derniers_fichiers_ouverts > a_conf->nb_max_derniers_fichiers_ouverts)
-			{
-				a_conf->nb_derniers_fichiers_ouverts = a_conf->nb_max_derniers_fichiers_ouverts;
-			}
-
-            a_conf->last_open_file = my_strdup (recent_array[0]);
-        }
-    }
-	grisbi_app_set_recent_files_array (recent_array);
+		a_conf->nb_derniers_fichiers_ouverts = g_strv_length (recent_array);
+		if (a_conf->nb_derniers_fichiers_ouverts > 0)
+			a_conf->last_open_file = my_strdup (recent_array[0]);
+		else
+			recent_array = NULL;
+	}
+	else
+		a_conf->nb_derniers_fichiers_ouverts = 0;
 
 	tmp_number = g_key_file_get_integer (config,
 									     "File",
@@ -382,6 +392,14 @@ gboolean grisbi_conf_load_app_config (void)
 		tmp_number = 3;
 	a_conf->nb_max_derniers_fichiers_ouverts = tmp_number;
 
+	if (a_conf->nb_derniers_fichiers_ouverts > a_conf->nb_max_derniers_fichiers_ouverts)
+	{
+		a_conf->nb_derniers_fichiers_ouverts = a_conf->nb_max_derniers_fichiers_ouverts;
+		if (recent_array)
+			recent_array[a_conf->nb_derniers_fichiers_ouverts] = NULL;
+	}
+	grisbi_app_set_recent_files_array (recent_array);
+
 	a_conf->sauvegarde_auto = g_key_file_get_boolean (config,
 													  "File",
 													  "sauvegarde-auto",
@@ -437,8 +455,8 @@ gboolean grisbi_conf_load_app_config (void)
     else
     {
         a_conf->browser_command = g_strdup (tmp_str);
-        g_free (tmp_str);
     }
+	g_free (tmp_str);
 
     tmp_str = g_key_file_get_string (config,
 									 "General",
@@ -450,8 +468,8 @@ gboolean grisbi_conf_load_app_config (void)
 			g_free (a_conf->current_theme);
 
         a_conf->current_theme = g_strdup (tmp_str);
-        g_free (tmp_str);
     }
+	g_free (tmp_str);
 
     a_conf->custom_fonte_listes = g_key_file_get_boolean (config,
 														  "General",
@@ -499,6 +517,7 @@ gboolean grisbi_conf_load_app_config (void)
 									 NULL);
     if (tmp_str == NULL || strlen (tmp_str) == 0)
     {
+		g_free(tmp_str);
         tmp_str = g_strdup (g_get_user_special_dir (G_USER_DIRECTORY_DOCUMENTS));
     }
 	else
@@ -643,28 +662,33 @@ gboolean grisbi_conf_load_app_config (void)
 											   NULL);
 
 	/* settings_prefs */
-    a_conf->prefs_archives_sort_order = g_key_file_get_boolean (config,
-														     "Prefs",
-															 "prefs-archives-sort-order",
+    a_conf->prefs_archives_sort_order = g_key_file_get_integer (config,
+																"Prefs",
+																"prefs-archives-sort-order",
+																NULL);
+    a_conf->prefs_fyear_sort_order = g_key_file_get_integer (config,
+															 "Prefs",
+															 "prefs-fyear-sort-order",
 															 NULL);
-    a_conf->prefs_fyear_sort_order = g_key_file_get_boolean (config,
-													      "Prefs",
-														  "prefs-fyear-sort-order",
-														  NULL);
     a_conf->prefs_height = g_key_file_get_integer (config,
-											    "Prefs",
-											    "prefs-height",
-											    NULL);
+												   "Prefs",
+												   "prefs-height",
+												   NULL);
 
-   	a_conf->prefs_panel_width = g_key_file_get_integer (config,
-												     "Prefs",
-												     "prefs-panel-width",
-												     NULL);
+	a_conf->prefs_notebook_width = g_key_file_get_integer (config,
+														   "Prefs",
+														   "prefs-notebook-width",
+														   NULL);
 
-    a_conf->prefs_width = g_key_file_get_integer (config,
-											   "Prefs",
-											   "prefs-width",
-											   NULL);
+	a_conf->prefs_panel_width = g_key_file_get_integer (config,
+														"Prefs",
+														"prefs-panel-width",
+														NULL);
+
+   	a_conf->prefs_width = g_key_file_get_integer (config,
+												  "Prefs",
+												  "prefs-width",
+												  NULL);
 
 	/* settings_scheduled */
     a_conf->balances_with_scheduled = g_key_file_get_boolean (config,
@@ -714,7 +738,6 @@ gboolean grisbi_conf_save_app_config (void)
 	gchar **recent_array;
 	const gchar *tmp_str;
 	gint i;
-	GError *error = NULL;
 	ConditionalMsg *warning;
 	GrisbiAppConf *a_conf;
 
@@ -771,12 +794,23 @@ gboolean grisbi_conf_save_app_config (void)
 							a_conf->sauvegarde_demarrage);
 
     /* settings_display */
-    switch (a_conf->display_toolbar)
+	if (a_conf->display_help)
+		g_key_file_set_string (config,
+							   "Display",
+							   "display-help",
+							   "Pdf");
+	else
+		g_key_file_set_string (config,
+							   "Display",
+							   "display-help",
+							   "Html");
+
+	switch (a_conf->display_toolbar)
     {
-        case GSB_BUTTON_TEXT:
+        case GTK_TOOLBAR_TEXT:
             tmp_str = "Text";
             break;
-        case GSB_BUTTON_ICON:
+        case GTK_TOOLBAR_ICONS:
             tmp_str = "Icons";
             break;
         default:
@@ -1078,28 +1112,33 @@ gboolean grisbi_conf_save_app_config (void)
                         	a_conf->panel_width);
 
 	/* settings_prefs */
-    g_key_file_set_boolean (config,
+    g_key_file_set_integer (config,
 							"Prefs",
 							"prefs-archives-sort-order",
 							a_conf->prefs_archives_sort_order);
-   g_key_file_set_boolean (config,
+   g_key_file_set_integer (config,
 						   "Prefs",
 						   "prefs-fyear-sort-order",
 						   a_conf->prefs_fyear_sort_order);
     g_key_file_set_integer (config,
 							"Prefs",
-                        	"prefs-height",
-                        	a_conf->prefs_height);
+							"prefs-height",
+							a_conf->prefs_height);
 
-    g_key_file_set_integer (config,
+	g_key_file_set_integer (config,
 							"Prefs",
-                        	"prefs-panel-width",
-                        	a_conf->prefs_panel_width);
+							"prefs-notebook-width",
+							a_conf->prefs_notebook_width);
 
-    g_key_file_set_integer (config,
+	g_key_file_set_integer (config,
 							"Prefs",
-                        	"prefs-width",
-                        	a_conf->prefs_width);
+							"prefs-panel-width",
+							a_conf->prefs_panel_width);
+
+	g_key_file_set_integer (config,
+							"Prefs",
+							"prefs-width",
+							a_conf->prefs_width);
 
 	/* settings_scheduled */
     g_key_file_set_boolean (config,
@@ -1135,7 +1174,7 @@ gboolean grisbi_conf_save_app_config (void)
 		utils_files_create_XDG_dir ();
 	}
 
-	if (!g_key_file_save_to_file (config, filename, &error))
+	if (!g_key_file_save_to_file (config, filename, NULL))
 	{
 		gchar* msg;
 
@@ -1162,7 +1201,6 @@ gboolean grisbi_conf_save_app_config (void)
  * \return
  **/
 
-#endif	/* USE_CONFIG_FILE */
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
