@@ -36,6 +36,7 @@
 #include <gtk/gtk.h>
 #include <libintl.h>
 
+#include "grisbi_app.h"
 #include "grisbi_osx.h"
 #include "erreur.h"
 
@@ -43,7 +44,6 @@
 #include <goffice/goffice.h>
 #endif
 
-extern gboolean darkmode;	/* from grisbi_app.c */
 
 /** 
  * Return the absolute path of the current executable
@@ -155,7 +155,7 @@ static gchar *set_macos_app_bundle_env(gchar const *program_dir)
     g_free(support_cache_dir);
 
     // GTK
-    // https://developer.gnome.org/gtk3/stable/gtk-running.html
+    // https://docs.gtk.org/gtk3/running.html
     my_setenv("GTK_EXE_PREFIX",  bundle_resources_dir);
     my_setenv("GTK_DATA_PREFIX", bundle_resources_dir);
 
@@ -179,6 +179,11 @@ static gchar *set_macos_app_bundle_env(gchar const *program_dir)
     my_setenv("GI_TYPELIB_PATH", bundle_resources_typelib_dir);
     g_free(bundle_resources_typelib_dir);
 
+	// OFX
+	gchar *bundle_resources_ofx_dir = g_build_filename(bundle_resources_share_dir, "libofx/dtd", NULL);
+	my_setenv("OFX_DTD_PATH", bundle_resources_ofx_dir);
+	g_free(bundle_resources_ofx_dir);
+
     // PATH
     const gchar *path_current = g_getenv("PATH");
     gchar *path_bin_dir = g_build_path(":", bundle_resources_bin_dir, path_current, NULL);
@@ -271,11 +276,11 @@ GSList *grisbi_osx_init(int *pargc, char *argv[]) {
         goffice_plugins_dirs = g_slist_prepend(NULL, local_plugins_dir);
         devel_debug(local_plugins_dir);
     }
+    g_free(bundle_resources_dir);
 #endif
 
-    g_free(bundle_resources_dir);
     devel_debug("MACOSX: initialization done.");
 
-    return goffice_plugins_dirs; /* should be g_slist_freed by caller */
+    return goffice_plugins_dirs;
 }
 
