@@ -46,15 +46,16 @@
 #include "gsb_data_form.h"
 #include "gsb_dirs.h"
 #include "gsb_file.h"
+#include "gsb_file_util.h"
 #include "gsb_select_icon.h"
 #include "import.h"
-#include "parametres.h"
 #include "prefs_page_bank.h"
 #include "structures.h"
 #include "traitement_variables.h"
 #include "utils.h"
 #include "utils_prefs.h"
 #include "utils_str.h"
+#include "utils_widgets.h"
 #include "widget_currency_popup.h"
 #include "erreur.h"
 /*END_INCLUDE*/
@@ -75,7 +76,7 @@ static GtkWidget *gsb_assistant_file_page_finish ( GtkWidget *assistant,
 /*START_EXTERN*/
 /*END_EXTERN*/
 
-enum file_assistant_page
+enum FileAssistantPage
 {
     FILE_ASSISTANT_INTRO= 0,
     FILE_ASSISTANT_PAGE_2,
@@ -254,6 +255,10 @@ GtkResponseType gsb_assistant_file_run ( gboolean first_opening,
 	if (nom_fichier_comptes)
 		g_free (nom_fichier_comptes);
 
+	/* check the file does not already exist */
+	if (! gsb_file_util_test_overwrite(grisbi_win_get_filename (NULL)))
+		return GTK_RESPONSE_CANCEL;
+
 	/* RAZ w_run->new_account_file */
 	w_run = grisbi_win_get_w_run ();
 	w_run->new_account_file = FALSE;
@@ -377,10 +382,10 @@ static GtkWidget *gsb_assistant_file_page_2 ( GtkWidget *assistant )
 #endif
 
     /* date format */
-    gsb_config_date_format_chosen ( vbox, GTK_ORIENTATION_HORIZONTAL );
+    utils_widget_date_format_chosen ( vbox, GTK_ORIENTATION_HORIZONTAL );
 
     /* decimal and thousands separator */
-    gsb_config_number_format_chosen ( vbox, GTK_ORIENTATION_HORIZONTAL );
+    utils_widget_number_format_chosen ( vbox, GTK_ORIENTATION_HORIZONTAL );
 
     /* Address */
     paddingbox = new_paddingbox_with_title ( vbox, FALSE, _("Your address") );
@@ -644,14 +649,23 @@ static gboolean gsb_assistant_file_choose_filename ( GtkWidget *button,
 						     GtkWidget *entry )
 {
     GtkWidget *dialog;
+	GtkWidget *button_cancel;
+	GtkWidget *button_OK;
     gchar *tmpstr;
 
-    dialog = gtk_file_chooser_dialog_new ( _("Create filename"),
-					   GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
-					   GTK_FILE_CHOOSER_ACTION_SAVE,
-					   "gtk-cancel", GTK_RESPONSE_CANCEL,
-					   "gtk-ok", GTK_RESPONSE_ACCEPT,
-					   NULL);
+    dialog = gtk_file_chooser_dialog_new (_("Create filename"),
+										  GTK_WINDOW ( grisbi_app_get_active_window (NULL)),
+										  GTK_FILE_CHOOSER_ACTION_SAVE,
+										  NULL, NULL,
+										  NULL);
+
+	button_cancel = gtk_button_new_with_label (_("Cancel"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, GTK_RESPONSE_CANCEL);
+	gtk_widget_set_can_default (button_cancel, TRUE);
+
+	button_OK = gtk_button_new_with_label (_("Validate"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_OK, GTK_RESPONSE_ACCEPT);
+	gtk_widget_set_can_default (button_OK, TRUE);
 
     tmpstr = g_path_get_basename (gtk_entry_get_text (GTK_ENTRY (entry)));
     gtk_file_chooser_set_current_name ( GTK_FILE_CHOOSER ( dialog ), tmpstr );
@@ -664,6 +678,8 @@ static gboolean gsb_assistant_file_choose_filename ( GtkWidget *button,
     gtk_file_chooser_set_do_overwrite_confirmation ( GTK_FILE_CHOOSER ( dialog ), TRUE);
     gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
 
+	gtk_widget_show_all (dialog);
+
     if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
     {
 	gchar *filename;
