@@ -1421,7 +1421,7 @@ gchar * gsb_debug_duplicate_budget_check (void)
 {
     GSList * tmp;
     gint num_duplicate = 0;
-    gchar * output = (gchar*)"";
+    gchar * output = NULL;
 
     tmp = budget_list;
     while ( tmp )
@@ -1438,16 +1438,25 @@ gchar * gsb_debug_duplicate_budget_check (void)
 	    /* Second comparison is just there to find only one of them. */
 	    if ( duplicate && duplicate > tmp_sous_budget )
 	    {
-	        gchar* tmpstr1 = output;
 		gchar* tmpstr2 = g_strdup_printf (
 		                        _("In <i>%s</i>, <i>%s</i> is a duplicate of <i>%s</i>.\n"),
 					budget -> budget_name,
 					((SubBudgetStruct *) tmp_sous_budget -> data) -> sub_budget_name,
 					((SubBudgetStruct *) duplicate -> data) -> sub_budget_name );
-		output = g_strconcat ( tmpstr1,
-				       tmpstr2,
-				       NULL );
-		g_free ( tmpstr2 );
+			if (output)
+			{
+				gchar* tmpstr1;
+
+				tmpstr1 = g_strconcat ( output,
+							   tmpstr2,
+							   NULL );
+				g_free(output);
+				g_free ( tmpstr2 );
+				output = tmpstr1;
+			}
+			else
+				output = tmpstr2;
+
 		num_duplicate ++;
 	    }
 	    tmp_sous_budget = tmp_sous_budget -> next;
@@ -1521,6 +1530,9 @@ void gsb_data_budget_set_budget_from_string ( gint transaction_number,
 {
     gchar **tab_char;
     gint budget_number;
+	GrisbiWinEtat *w_etat;
+
+	w_etat = grisbi_win_get_w_etat ();
 
     /* the simpliest is to split in 2 parts, transaction and scheduled,
      * but the 2 parts are exactly the same, exept the call to the functions */
@@ -1537,7 +1549,7 @@ void gsb_data_budget_set_budget_from_string ( gint transaction_number,
 
         /* we don't mind if tab_char exists and others, all the checks will be done in ...get_number_by_name */
         budget_number = gsb_data_budget_get_number_by_name ( g_strstrip ( tab_char[0] ),
-                                !etat.combofix_force_category,
+                                !w_etat->combofix_force_category,
                                 gsb_data_transaction_get_amount ( transaction_number ).mantissa < 0 );
         gsb_data_transaction_set_budgetary_number ( transaction_number, budget_number );
 
@@ -1545,7 +1557,7 @@ void gsb_data_budget_set_budget_from_string ( gint transaction_number,
             gsb_data_transaction_set_sub_budgetary_number ( transaction_number,
                                 gsb_data_budget_get_sub_budget_number_by_name ( budget_number,
                                                         g_strstrip (tab_char[1]),
-                                                        !etat.combofix_force_category));
+                                                        !w_etat->combofix_force_category));
     }
     else
     {
@@ -1562,7 +1574,7 @@ void gsb_data_budget_set_budget_from_string ( gint transaction_number,
 
         /* we don't mind if tab_char exists and others, all the checks will be done in ...get_number_by_name */
         budget_number = gsb_data_budget_get_number_by_name ( tab_char[0],
-                                     !etat.combofix_force_category,
+                                     !w_etat->combofix_force_category,
                                      gsb_data_scheduled_get_amount (transaction_number).mantissa <0 );
         gsb_data_scheduled_set_budgetary_number ( transaction_number,
                                 budget_number );
@@ -1570,7 +1582,7 @@ void gsb_data_budget_set_budget_from_string ( gint transaction_number,
             gsb_data_scheduled_set_sub_budgetary_number ( transaction_number,
                                   gsb_data_budget_get_sub_budget_number_by_name ( budget_number,
                                                           tab_char[1],
-                                                          !etat.combofix_force_category));
+                                                          !w_etat->combofix_force_category));
     }
     g_strfreev (tab_char);
 }
