@@ -86,8 +86,6 @@ struct _SubCategoryStruct
     GsbReal sub_category_balance;
 };
 
-
-
 /*START_STATIC*/
 static void _gsb_data_category_free ( CategoryStruct *category );
 static void _gsb_data_sub_category_free ( SubCategoryStruct *sub_category );
@@ -123,7 +121,13 @@ static SubCategoryStruct *sub_category_buffer;
  * the number of the empty category is 0 */
 static CategoryStruct *empty_category = NULL;
 
-
+/* used to choose the kind of categories list */
+enum CategoryChoiceValues {
+    CATEGORY_CHOICE_NONE = 0,
+    CATEGORY_CHOICE_DEFAULT,
+    CATEGORY_CHOICE_ASSOCIATION,
+    CATEGORY_CHOICE_LIBERAL
+};
 
 /**
  * set the categories global variables to NULL, usually when we init all the global variables
@@ -682,7 +686,9 @@ gboolean gsb_data_category_fill_transaction_by_string ( gint transaction_number,
 {
     gchar **tab_char;
     gint category_number = 0;
+	GrisbiWinEtat *w_etat;
 
+	w_etat = grisbi_win_get_w_etat ();
     if (!string
 	||
 	!strlen (string))
@@ -701,7 +707,7 @@ gboolean gsb_data_category_fill_transaction_by_string ( gint transaction_number,
     if (tab_char[0])
     {
         category_number = gsb_data_category_get_number_by_name ( tab_char[0],
-                            !etat.combofix_force_category,
+                            !w_etat->combofix_force_category,
                             gsb_data_mix_get_amount (
                             transaction_number, is_transaction).mantissa <0 );
 	    gsb_data_mix_set_category_number ( transaction_number,
@@ -714,7 +720,7 @@ gboolean gsb_data_category_fill_transaction_by_string ( gint transaction_number,
         gsb_data_mix_set_sub_category_number ( transaction_number,
 					        gsb_data_category_get_sub_category_number_by_name ( category_number,
 																			   tab_char[1],
-																			   !etat.combofix_force_category ),
+																			   !w_etat->combofix_force_category ),
 					        is_transaction );
     }
     else
@@ -1593,7 +1599,7 @@ gchar * gsb_debug_duplicate_categ_check (void)
 {
     GSList * tmp;
     gint num_duplicate = 0;
-    gchar * output = (gchar*)"";
+    gchar * output = NULL;
 
     tmp = category_list;
     while ( tmp )
@@ -1610,16 +1616,22 @@ gchar * gsb_debug_duplicate_categ_check (void)
 	    /* Second comparison is just there to find only one of them. */
 	    if ( duplicate && duplicate > tmp_sous_categ )
 	    {
-	        gchar* tmpstr1 = output;
 		gchar* tmpstr2 = g_strdup_printf (
 				_("In <i>%s</i>, <i>%s</i> is a duplicate of <i>%s</i>.\n"),
 				categ -> category_name,
 				((SubCategoryStruct *) tmp_sous_categ -> data) -> sub_category_name,
 				((SubCategoryStruct *) duplicate -> data) -> sub_category_name );
-		output = g_strconcat ( tmpstr1,
+			if (output)
+			{
+				gchar *tmpstr1 = output;
+				output = g_strconcat ( tmpstr1,
 				       tmpstr2,
 				       NULL );
-		g_free ( tmpstr2 );
+				g_free ( tmpstr1 );
+				g_free ( tmpstr2 );
+			}
+			else
+				output = tmpstr2;
 		num_duplicate ++;
 	    }
 	    tmp_sous_categ = tmp_sous_categ -> next;
@@ -1804,6 +1816,9 @@ void gsb_data_category_set_category_from_string (gint transaction_number,
 {
     gchar **tab_char;
     gint category_number;
+	GrisbiWinEtat *w_etat;
+
+	w_etat = grisbi_win_get_w_etat ();
 
     /* the simpliest is to split in 2 parts, transaction and scheduled,
      * but the 2 parts are exactly the same, exept the call to the functions */
@@ -1820,7 +1835,7 @@ void gsb_data_category_set_category_from_string (gint transaction_number,
 
         /* we don't mind if tab_char exists and others, all the checks will be done in ...get_number_by_name */
         category_number = gsb_data_category_get_number_by_name (g_strstrip (tab_char[0]),
-																!etat.combofix_force_category,
+																!w_etat->combofix_force_category,
 																gsb_data_transaction_get_amount
 																(transaction_number).mantissa < 0);
         gsb_data_transaction_set_category_number (transaction_number, category_number);
@@ -1830,7 +1845,7 @@ void gsb_data_category_set_category_from_string (gint transaction_number,
 														  gsb_data_category_get_sub_category_number_by_name
 														  (category_number,
 														   g_strstrip (tab_char[1]),
-														   !etat.combofix_force_category));
+														   !w_etat->combofix_force_category));
     }
     else
     {
@@ -1845,7 +1860,7 @@ void gsb_data_category_set_category_from_string (gint transaction_number,
 
         /* we don't mind if tab_char exists and others, all the checks will be done in ...get_number_by_name */
         category_number = gsb_data_category_get_number_by_name (tab_char[0],
-																!etat.combofix_force_category,
+																!w_etat->combofix_force_category,
 																gsb_data_scheduled_get_amount
 																(transaction_number).mantissa <0);
         gsb_data_scheduled_set_category_number (transaction_number, category_number);
@@ -1854,7 +1869,7 @@ void gsb_data_category_set_category_from_string (gint transaction_number,
 														gsb_data_category_get_sub_category_number_by_name
 														(category_number,
 														 tab_char[1],
-														 !etat.combofix_force_category));
+														 !w_etat->combofix_force_category));
     }
     g_strfreev (tab_char);
 }
