@@ -46,14 +46,14 @@
 /**
  * describe the invalid numbers
  * */
-enum fyear_invalid {
+enum FyearInvalid {
     FYEAR_INVALID_DATE_ORDER = 1,
     FYEAR_INVALID_CROSS,
     FYEAR_INVALID_DATE
 };
 
 /*START_STATIC*/
-static void _gsb_data_fyear_free ( FyearStruct *fyear );
+static void _gsb_data_fyear_free (FyearStruct *fyear);
 static gpointer gsb_data_fyear_get_structure ( gint fyear_number );
 static gint gsb_data_fyear_max_number ( void );
 /*END_STATIC*/
