@@ -5,8 +5,8 @@
 /*                                                                               */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)               */
 /*                      2003-2008 Benjamin Drieu (bdrieu@april.org)              */
-/*          2008-2018 Pierre Biava (grisbi@pierre.biava.name)                    */
-/*          https://www.grisbi.org/                                               */
+/*          2008-2023 Pierre Biava (grisbi@pierre.biava.name)                    */
+/*          https://www.grisbi.org/                                              */
 /*                                                                               */
 /*     This program is free software; you can redistribute it and/or modify      */
 /*     it under the terms of the GNU General Public License as published by      */
@@ -24,7 +24,6 @@
 /*                                                                               */
 /* *******************************************************************************/
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -51,18 +50,15 @@
 #include "gsb_locale.h"
 #include "structures.h"
 #include "erreur.h"
+
 #ifdef __APPLE__
-#   include "grisbi_osx.h"
+# include "grisbi_osx.h"
 #endif
 /*END_INCLUDE*/
 
 /*START_EXTERN*/
 /*END_EXTERN*/
 
-
-
-
-
 /**
  * Main function
  *
@@ -73,12 +69,18 @@
  */
 int main (int argc, char **argv)
 {
-    GrisbiApp *app;
 	gint status;
-#if defined(HAVE_GOFFICE) || defined(__APPLE__)
-    GSList *goffice_plugins_dirs = NULL;
+	GSList *goffice_plugins_dirs = NULL;
+
+#ifdef EARLY_DEBUG
+	debug_start_log_file ();
 #endif
-	/* On force l'utilisation de X11 en attendant que grisbi fonctionne correctement sous wayland */
+
+#ifdef __APPLE__
+	goffice_plugins_dirs = grisbi_osx_init (&argc, argv);
+#endif
+
+	 /* On force l'utilisation de X11 en attendant que grisbi fonctionne correctement sous wayland */
 #ifdef GDK_WINDOWING_WAYLAND
 	#ifdef GDK_WINDOWING_X11
 		gdk_set_allowed_backends ("x11");
@@ -87,60 +89,33 @@ int main (int argc, char **argv)
 	#endif
 #endif
 
-#ifdef EARLY_DEBUG
-	debug_start_log_file ();
-#endif
-
-#ifdef __APPLE__
-     goffice_plugins_dirs = grisbi_osx_init(&argc, argv);
-#endif
-
 	/* On commence par initialiser les répertoires */
-    gsb_dirs_init (argv[0]);
+	gsb_dirs_init (argv[0]);
 
-    /* Setup locale/gettext */
-    setlocale (LC_ALL, "");
-    bindtextdomain (GETTEXT_PACKAGE, gsb_dirs_get_locale_dir ());
-    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-    textdomain (GETTEXT_PACKAGE);
+	/* Setup locale/gettext */
+	setlocale (LC_ALL, "");
+	bindtextdomain (GETTEXT_PACKAGE, gsb_dirs_get_locale_dir ());
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
 
 #ifdef HAVE_GOFFICE
-    /* initialisation libgoffice */
-    libgoffice_init ();
-    /* Initialize plugins manager */
-    go_plugins_init (NULL, NULL, NULL, goffice_plugins_dirs, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
-    /* Note: go_plugins_init will g_slist_free(goffice_plugins_dirs) ! */
+	/* initialisation libgoffice */
+	libgoffice_init ();
+	/* Initialize plugins manager */
+	go_plugins_init (NULL, NULL, NULL, goffice_plugins_dirs, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
+	/* Note: go_plugins_init will g_slist_free(goffice_plugins_dirs) ! */
+#else
+	(void) goffice_plugins_dirs; /* Avoid warning */
 #endif /* HAVE_GOFFICE */
 
-    app = g_object_new (GRISBI_APP_TYPE,
-                        "application-id",   "org.gtk.grisbi",
-                        "flags",            G_APPLICATION_HANDLES_COMMAND_LINE | G_APPLICATION_NON_UNIQUE,
-                        "register-session", TRUE,
-                        NULL);
-
-    /* option en attente : G_APPLICATION_HANDLES_OPEN,voir GApplicationFlags pour détails */
-
-    status = g_application_run (G_APPLICATION (app), argc, argv);
-
-    g_object_unref (app);
+	/* on execute la boucle principale de grisbi */
+	status = g_application_run (G_APPLICATION (grisbi_app_new ()), argc, argv);
 
 #ifdef HAVE_GOFFICE
-    /* liberation libgoffice */
-    libgoffice_shutdown ();
+	/* liberation libgoffice */
+	libgoffice_shutdown ();
 #endif /* HAVE_GOFFICE */
 
-
-    return status;
+	return status;
 }
 
-
-/**
- *
- *
- * \param
- *
- * \return
- * */
-/* Local Variables: */
-/* c-basic-offset: 4 */
-/* End: */
