@@ -53,6 +53,7 @@
 #include "ofx.h"
 
 #include "dialog.h"
+#include "grisbi_win.h"
 #include "gsb_real.h"
 #include "structures.h"
 #include "utils_str.h"
@@ -111,8 +112,11 @@ static int ofx_proc_account_cb (struct OfxAccountData data,
 
 	if (data.account_id_valid)
 	{
+		gchar *tmp_str;
 		compte_ofx_importation_en_cours->id_compte = g_convert (data.account_id, -1, "UTF-8", coding_system, NULL, NULL, NULL);
-		compte_ofx_importation_en_cours->nom_de_compte = gsb_import_unique_imported_name (g_convert (data.account_name, -1, "UTF-8", coding_system, NULL, NULL, NULL));
+		tmp_str = g_convert (data.account_name, -1, "UTF-8", coding_system, NULL, NULL, NULL);
+		compte_ofx_importation_en_cours->nom_de_compte = gsb_import_unique_imported_name (tmp_str);
+		g_free(tmp_str);
 		compte_ofx_importation_en_cours->filename = ofx_filename;
 	}
 
@@ -362,6 +366,10 @@ static int ofx_proc_transaction_cb (struct OfxTransactionData data,
 	/* mais tout n'est pas utilisé par les banques... */
 	if (data.transactiontype_valid)
 	{
+		GrisbiWinEtat *w_etat;
+
+		w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
+
 		switch (data.transactiontype)
 		{
 			case OFX_CHECK:
@@ -424,7 +432,7 @@ static int ofx_proc_transaction_cb (struct OfxTransactionData data,
 			case OFX_DEBIT:
 			case OFX_CREDIT:
 			case OFX_OTHER:
-				if (etat.extract_number_for_check)
+				if (w_etat->extract_number_for_check)
 				{
 					gchar *str_to_free = NULL;
 
@@ -478,7 +486,7 @@ gboolean recuperation_donnees_ofx (GtkWidget *assistant,
 	ofx_filename = imported->name;
 	coding_system = imported->coding_system;
 
-	devel_print_str (imported->name);
+	devel_debug (imported->name);
 
 	ofx_context = libofx_get_new_context();
 	ofx_set_status_cb (ofx_context, ofx_proc_status_cb, NULL);
@@ -502,7 +510,7 @@ gboolean recuperation_donnees_ofx (GtkWidget *assistant,
 		account->real_filename = g_strdup (ofx_filename);
 		account->origine = g_strdup ("OFX");
 		gsb_import_register_account_error (account);
-		devel_print_str (account->nom_de_compte);
+		devel_debug (account->nom_de_compte);
 
 		return FALSE ;
 	}
