@@ -5,7 +5,7 @@
 /*                                                                               */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)               */
 /*                      2003-2008 Benjamin Drieu (bdrieu@april.org)              */
-/*          2008-2020 Pierre Biava (grisbi@pierre.biava.name)                    */
+/*          2008-2022 Pierre Biava (grisbi@pierre.biava.name)                    */
 /*          https://www.grisbi.org/                                              */
 /*                                                                               */
 /*     This program is free software; you can redistribute it and/or modify      */
@@ -39,6 +39,7 @@
 /*START_INCLUDE*/
 #include "prefs_page_bet_account.h"
 #include "bet_data.h"
+#include "dialog.h"
 #include "gsb_data_account.h"
 #include "bet_data_finance.h"
 #include "bet_hist.h"
@@ -47,7 +48,7 @@
 #include "gsb_calendar_entry.h"
 #include "gsb_fyear.h"
 #include "navigation.h"
-#include "prefs_widget_loan.h"
+#include "widget_loan.h"
 #include "structures.h"
 #include "utils.h"
 #include "utils_dates.h"
@@ -58,7 +59,7 @@
 /*END_INCLUDE*/
 
 /*START_STATIC*/
-static void prefs_page_bet_account_select_bank_card_toggle (GtkToggleButton *button,
+static gboolean prefs_page_bet_account_changed (GtkWidget *combo,
 															PrefsPageBetAccount *page);
 /*END_STATIC*/
 
@@ -74,14 +75,33 @@ struct _PrefsPageBetAccountPrivate
 	GtkWidget *			notebook_bet_account;
 	GtkWidget *			combo_bet_account;
 	GtkWidget *			hbox_bet_select_account;
-    GtkWidget *			checkbutton_use_bet_module;
+	GtkWidget *			checkbutton_use_bet_module;
 	GtkWidget *			hbox_bet_credit_card;
-    GtkWidget *			checkbutton_bet_credit_card;
+	GtkWidget *			checkbutton_bet_credit_card;
 	GtkWidget *			vbox_bank_cash_account;
+
 	GtkWidget *			hbox_forecast_data;
 	GtkWidget *			vbox_forecast_data;
-	GtkWidget *			hbox_historical_data;
-	GtkWidget *			vbox_historical_data;
+	GtkWidget *			radiobutton_source_transaction0;
+	GtkWidget *			radiobutton_source_transaction1;
+	GtkWidget *			radiobutton_source_transaction2;
+	GtkWidget *			radiobutton_source_transaction3;
+	GtkWidget *			radiobutton_source_scheduled0;
+	GtkWidget *			radiobutton_source_scheduled1;
+	GtkWidget *			radiobutton_source_scheduled2;
+	GtkWidget *			radiobutton_source_scheduled3;
+	GtkWidget *			radiobutton_source_futur0;
+	GtkWidget *			radiobutton_source_futur1;
+	GtkWidget *			radiobutton_source_futur2;
+	GtkWidget *			radiobutton_source_futur3;
+
+	GtkWidget *			hbox_hist_data;
+	GtkWidget *			vbox_hist_data;
+	GtkWidget *			vbox_hist_card_account_use_data;
+	GtkWidget *			label_hist_card_account_use_data;
+	GtkWidget *			vbox_hist_main_account_use_data;
+	GtkWidget *			checkbutton_hist_main_account_use_data;
+	GtkWidget *			label_hist_main_account_use_data;
 	GtkWidget *			vbox_liabilities_account;
 	GtkWidget *			vbox_credit_data;
 	GtkWidget *			notebook_credit_data;
@@ -95,6 +115,33 @@ G_DEFINE_TYPE_WITH_PRIVATE (PrefsPageBetAccount, prefs_page_bet_account, GTK_TYP
 /******************************************************************************/
 /* Private functions                                                          */
 /******************************************************************************/
+/**
+ *
+ *
+ * \param
+ * \param
+ *
+ * \return
+ **/
+static void prefs_page_bet_account_set_label_bet_hist_main_account_use_data (gint number,
+																			 PrefsPageBetAccountPrivate *priv)
+{
+	gchar *tmp_str;
+
+	if (number == 1)
+		tmp_str = g_strdup (_("(These data are aggregated with those "
+							  "of a deferred debit card account)"));
+	else
+		tmp_str = g_strdup_printf (_("(These data are aggregated with those "
+									 "of %d deferred debit card accounts)"),
+								   number);
+
+	gtk_label_set_text (GTK_LABEL (priv->label_hist_main_account_use_data), tmp_str);
+	gtk_widget_show (priv->vbox_hist_main_account_use_data);
+
+	g_free (tmp_str);
+}
+
 /**
  * called for a change in automem_radiobutton3
  *
@@ -103,29 +150,26 @@ G_DEFINE_TYPE_WITH_PRIVATE (PrefsPageBetAccount, prefs_page_bet_account, GTK_TYP
  *
  * \return FALSE
  **/
-static gboolean prefs_page_bet_account_select_label_changed (GtkWidget *checkbutton,
-                                                			 GdkEventButton *event,
-                                                			 gpointer data)
+static void prefs_page_bet_account_select_label_toggled (GtkWidget *togglebutton,
+														 gpointer data)
 {
-    gint value;
-    gint origine;
-    gint account_number;
+	gint value;
+	gint origine;
+	gint account_number;
 
-    devel_debug (NULL);
+	devel_debug (NULL);
 
-    /* we are on the active button, so save the value for it */
-    value = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (checkbutton), "pointer"));
-    origine = GPOINTER_TO_INT (data);
-    account_number = gsb_account_get_account_from_combo ();
+	/* we are on the active button, so save the value for it */
+	value = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (togglebutton), "pointer"));
+	origine = GPOINTER_TO_INT (data);
+	account_number = gsb_account_get_account_from_combo ();
 
-    gsb_data_account_set_bet_select_label (account_number, origine, value);
+	gsb_data_account_set_bet_select_label (account_number, origine, value);
 
-    utils_prefs_gsb_file_set_modified ();
+	utils_prefs_gsb_file_set_modified ();
 
-    gsb_data_account_set_bet_maj (account_number, BET_MAJ_ESTIMATE);
-    bet_data_update_bet_module (account_number, -1);
-
-    return FALSE;
+	gsb_data_account_set_bet_maj (account_number, BET_MAJ_ESTIMATE);
+	bet_data_update_bet_module (account_number, -1);
 }
 
 /**
@@ -135,79 +179,155 @@ static gboolean prefs_page_bet_account_select_label_changed (GtkWidget *checkbut
  *
  * \return
  **/
-static GtkWidget *prefs_page_bet_account_get_select_labels_widget (void)
+static void prefs_page_bet_account_init_select_labels_widget (PrefsPageBetAccountPrivate *priv)
 {
-    GtkWidget *vbox;
-    GtkWidget *label;
-    GtkWidget *button;
-    gint origine;
-    gint select;
+	gint origine;
+	gint select;
 
-    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+	/* set labels for transactions */
+	origine = SPP_ORIGIN_TRANSACTION;
+	select = gsb_data_account_get_bet_select_label (gsb_account_get_account_from_combo (), origine);
+	switch (select)
+	{
+		case 0:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_source_transaction0), TRUE);
+			break;
 
-    /* set labels for transactions */
-    origine = SPP_ORIGIN_TRANSACTION;
-    select = gsb_data_account_get_bet_select_label (gsb_account_get_account_from_combo (), origine);
-    label = gtk_label_new (_("Labels for transactions:"));
-    utils_labels_set_alignment (GTK_LABEL (label), 0, 0.5);
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-    gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 5);
+		case 1:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_source_transaction1), TRUE);
+			break;
 
-    button = gsb_automem_radiobutton3_new (_("By default"),
-                                           _("Categories"),
-                                           _("Budgetary lines"),
-                                           &select,
-                                           G_CALLBACK (prefs_page_bet_account_select_label_changed),
-                                           GINT_TO_POINTER (origine),
-                                           GTK_ORIENTATION_HORIZONTAL);
-    gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+		case 2:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_source_transaction2), TRUE);
+			break;
 
+		case 3:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_source_transaction3), TRUE);
+			break;
+	}
 
-    /* set labels for scheduled */
-    origine = SPP_ORIGIN_SCHEDULED;
-    select = gsb_data_account_get_bet_select_label (gsb_account_get_account_from_combo (),
-                        origine);
-    label = gtk_label_new (_("Labels for scheduled transactions:"));
-    utils_labels_set_alignment (GTK_LABEL (label), 0, 0.5);
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-    gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 5);
+	/* set data for each widget */
+	g_object_set_data (G_OBJECT (priv->radiobutton_source_transaction0), "pointer", GINT_TO_POINTER (0));
+	g_object_set_data (G_OBJECT (priv->radiobutton_source_transaction1), "pointer", GINT_TO_POINTER (1));
+	g_object_set_data (G_OBJECT (priv->radiobutton_source_transaction2), "pointer", GINT_TO_POINTER (2));
+	g_object_set_data (G_OBJECT (priv->radiobutton_source_transaction3), "pointer", GINT_TO_POINTER (3));
 
-    button = gsb_automem_radiobutton3_new (_("By default"),
-					    _("Categories"),
-					    _("Budgetary lines"),
-					    &select,
-                        G_CALLBACK (prefs_page_bet_account_select_label_changed),
-                        GINT_TO_POINTER (origine),
-                        GTK_ORIENTATION_HORIZONTAL);
-    gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+	/* Connect signal */
+	g_signal_connect (G_OBJECT (priv->radiobutton_source_transaction0),
+					  "toggled",
+					  G_CALLBACK (prefs_page_bet_account_select_label_toggled),
+					  GINT_TO_POINTER (SPP_ORIGIN_TRANSACTION));
 
-    /* set labels for futur data */
-    origine = SPP_ORIGIN_FUTURE;
-    select = gsb_data_account_get_bet_select_label (gsb_account_get_account_from_combo (), origine);
-    label = gtk_label_new (_("Labels for futur data:"));
-    utils_labels_set_alignment (GTK_LABEL (label), 0, 0.5);
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-    gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 5);
+	g_signal_connect (G_OBJECT (priv->radiobutton_source_transaction1),
+					  "toggled",
+					  G_CALLBACK (prefs_page_bet_account_select_label_toggled),
+					  GINT_TO_POINTER (SPP_ORIGIN_TRANSACTION));
 
-    button = gsb_automem_radiobutton3_new (_("By default"),
-					    _("Categories"),
-					    _("Budgetary lines"),
-					    &select,
-                        G_CALLBACK (prefs_page_bet_account_select_label_changed),
-                        GINT_TO_POINTER (origine),
-                        GTK_ORIENTATION_HORIZONTAL);
-    gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+	g_signal_connect (G_OBJECT (priv->radiobutton_source_transaction2),
+					  "toggled",
+					  G_CALLBACK (prefs_page_bet_account_select_label_toggled),
+					  GINT_TO_POINTER (SPP_ORIGIN_TRANSACTION));
 
-    label = gtk_label_new (_("Order by default if the data are not zero:\n"
-							 "\tnotes, payee, category and budgetary line."));
-    gtk_label_set_use_markup (GTK_LABEL(label), TRUE);
-    utils_labels_set_alignment (GTK_LABEL (label), 0, 0.5);
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-    gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 5) ;
+	g_signal_connect (G_OBJECT (priv->radiobutton_source_transaction3),
+					  "toggled",
+					  G_CALLBACK (prefs_page_bet_account_select_label_toggled),
+					  GINT_TO_POINTER (SPP_ORIGIN_TRANSACTION));
 
-    gtk_widget_show_all (vbox);
+	/* set labels for scheduled */
+	origine = SPP_ORIGIN_SCHEDULED;
+	select = gsb_data_account_get_bet_select_label (gsb_account_get_account_from_combo (), origine);
+	switch (select)
+	{
+		case 0:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_source_scheduled0), TRUE);
+			break;
 
-    return vbox;
+		case 1:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_source_scheduled1), TRUE);
+			break;
+
+		case 2:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_source_scheduled2), TRUE);
+			break;
+
+		case 3:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_source_scheduled3), TRUE);
+			break;
+	}
+
+	/* set data for each widget */
+	g_object_set_data (G_OBJECT (priv->radiobutton_source_scheduled0), "pointer", GINT_TO_POINTER (0));
+	g_object_set_data (G_OBJECT (priv->radiobutton_source_scheduled1), "pointer", GINT_TO_POINTER (1));
+	g_object_set_data (G_OBJECT (priv->radiobutton_source_scheduled2), "pointer", GINT_TO_POINTER (2));
+	g_object_set_data (G_OBJECT (priv->radiobutton_source_scheduled3), "pointer", GINT_TO_POINTER (3));
+
+	/* Connect signal */
+	g_signal_connect (G_OBJECT (priv->radiobutton_source_scheduled0),
+					  "toggled",
+					  G_CALLBACK (prefs_page_bet_account_select_label_toggled),
+					  GINT_TO_POINTER (SPP_ORIGIN_SCHEDULED));
+
+	g_signal_connect (G_OBJECT (priv->radiobutton_source_scheduled1),
+					  "toggled",
+					  G_CALLBACK (prefs_page_bet_account_select_label_toggled),
+					  GINT_TO_POINTER (SPP_ORIGIN_SCHEDULED));
+
+	g_signal_connect (G_OBJECT (priv->radiobutton_source_scheduled2),
+					  "toggled",
+					  G_CALLBACK (prefs_page_bet_account_select_label_toggled),
+					  GINT_TO_POINTER (SPP_ORIGIN_SCHEDULED));
+	g_signal_connect (G_OBJECT (priv->radiobutton_source_scheduled3),
+					  "toggled",
+					  G_CALLBACK (prefs_page_bet_account_select_label_toggled),
+					  GINT_TO_POINTER (SPP_ORIGIN_SCHEDULED));
+
+	/* set labels for futur data */
+	origine = SPP_ORIGIN_FUTURE;
+	select = gsb_data_account_get_bet_select_label (gsb_account_get_account_from_combo (), origine);
+	switch (select)
+	{
+		case 0:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_source_futur0), TRUE);
+			break;
+
+		case 1:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_source_futur1), TRUE);
+			break;
+
+		case 2:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_source_futur2), TRUE);
+			break;
+
+		case 3:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->radiobutton_source_futur3), TRUE);
+			break;
+	}
+
+	/* set data for each widget */
+	g_object_set_data (G_OBJECT (priv->radiobutton_source_futur0), "pointer", GINT_TO_POINTER (0));
+	g_object_set_data (G_OBJECT (priv->radiobutton_source_futur1), "pointer", GINT_TO_POINTER (1));
+	g_object_set_data (G_OBJECT (priv->radiobutton_source_futur2), "pointer", GINT_TO_POINTER (2));
+	g_object_set_data (G_OBJECT (priv->radiobutton_source_futur3), "pointer", GINT_TO_POINTER (3));
+
+	/* Connect signal */
+	g_signal_connect (G_OBJECT (priv->radiobutton_source_futur0),
+					  "toggled",
+					  G_CALLBACK (prefs_page_bet_account_select_label_toggled),
+					  GINT_TO_POINTER (SPP_ORIGIN_FUTURE));
+
+	g_signal_connect (G_OBJECT (priv->radiobutton_source_futur1),
+					  "toggled",
+					  G_CALLBACK (prefs_page_bet_account_select_label_toggled),
+					  GINT_TO_POINTER (SPP_ORIGIN_FUTURE));
+
+	g_signal_connect (G_OBJECT (priv->radiobutton_source_futur2),
+					  "toggled",
+					  G_CALLBACK (prefs_page_bet_account_select_label_toggled),
+					  GINT_TO_POINTER (SPP_ORIGIN_FUTURE));
+	g_signal_connect (G_OBJECT (priv->radiobutton_source_futur3),
+					  "toggled",
+					  G_CALLBACK (prefs_page_bet_account_select_label_toggled),
+					  GINT_TO_POINTER (SPP_ORIGIN_FUTURE));
 }
 
 /**
@@ -327,7 +447,7 @@ static void prefs_page_bet_account_initialise_loan_data (gint account_number,
 		s_loan = bet_data_loan_struct_loan_init ();
 		s_loan->account_number = account_number;
 		s_loan->version_number = -1;
-		widget = GTK_WIDGET (prefs_widget_loan_new (s_loan));
+		widget = GTK_WIDGET (widget_loan_new (s_loan));
 		label = gtk_label_new (_("Initial loan"));
 		utils_widget_set_padding (label, MARGIN_BOX, 0);
 		gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook_credit_data), widget, label);
@@ -344,7 +464,7 @@ static void prefs_page_bet_account_initialise_loan_data (gint account_number,
 
 		s_loan = (LoanStruct *) tmp_list->data;
 		index = s_loan->version_number;
-		widget = GTK_WIDGET (prefs_widget_loan_new (s_loan));
+		widget = GTK_WIDGET (widget_loan_new (s_loan));
 		if (!index)
 			label = gtk_label_new (_("Initial loan"));
 		else
@@ -360,7 +480,8 @@ static void prefs_page_bet_account_initialise_loan_data (gint account_number,
 		tmp_list = tmp_list->next;
 	}
 }
-static void prefs_page_bet_account_initialise_select_historical_data (gint account_number,
+
+static void prefs_page_bet_account_initialise_select_hist_data (gint account_number,
                                                                       GtkWidget *notebook)
 {
     GtkWidget *widget;
@@ -379,7 +500,7 @@ static void prefs_page_bet_account_initialise_select_historical_data (gint accou
 
     param = gsb_data_account_get_bet_hist_fyear (account_number);
     widget = g_object_get_data (G_OBJECT (notebook), "bet_config_hist_fyear_combo");
-    bet_historical_set_fyear_from_combobox (widget, param);
+    bet_hist_set_fyear_from_combobox (widget, param);
 }
 
 /**
@@ -409,19 +530,19 @@ static void prefs_page_bet_account_show_hide_parameters (gint account_number,
 			case BET_ONGLETS_PREV:
 				gtk_widget_hide (priv->hbox_bet_credit_card);
 				gtk_widget_show (priv->hbox_forecast_data);
-				gtk_widget_show (priv->hbox_historical_data);
+				gtk_widget_show (priv->hbox_hist_data);
 				gtk_widget_hide (priv->vbox_liabilities_account);
 				break;
 			case BET_ONGLETS_HIST:
 				gtk_widget_hide (priv->hbox_bet_credit_card);
 				gtk_widget_hide (priv->hbox_forecast_data);
-				gtk_widget_show (priv->hbox_historical_data);
+				gtk_widget_show (priv->hbox_hist_data);
 				gtk_widget_hide (priv->vbox_liabilities_account);
 				break;
 			case BET_ONGLETS_CAP:
 				gtk_widget_show (priv->hbox_bet_credit_card);
 				gtk_widget_hide (priv->hbox_forecast_data);
-				gtk_widget_hide (priv->hbox_historical_data);
+				gtk_widget_hide (priv->hbox_hist_data);
 				gtk_widget_show (priv->vbox_liabilities_account);
 				break;
 			case BET_ONGLETS_SANS:
@@ -429,7 +550,7 @@ static void prefs_page_bet_account_show_hide_parameters (gint account_number,
 			default:
 				gtk_widget_hide (priv->hbox_bet_credit_card);
 				gtk_widget_hide (priv->hbox_forecast_data);
-				gtk_widget_hide (priv->hbox_historical_data);
+				gtk_widget_hide (priv->hbox_hist_data);
 				gtk_widget_hide (priv->vbox_liabilities_account);
 				break;
         }
@@ -438,11 +559,134 @@ static void prefs_page_bet_account_show_hide_parameters (gint account_number,
     {
         gtk_widget_hide (priv->hbox_bet_credit_card);
         gtk_widget_hide (priv->hbox_forecast_data);
-        gtk_widget_hide (priv->hbox_historical_data);
+        gtk_widget_hide (priv->hbox_hist_data);
         gtk_widget_hide (priv->vbox_liabilities_account);
     }
 }
 
+/**
+ * callback checkbutton select_bank_card
+ *
+ * \param toggle button
+ * \param page
+ *
+ * \return
+ **/
+static void prefs_page_bet_account_select_bank_card_toggle (GtkToggleButton *button,
+															PrefsPageBetAccount *page)
+{
+    gint account_number;
+	PrefsPageBetAccountPrivate *priv;
+
+	devel_debug (NULL);
+	priv = prefs_page_bet_account_get_instance_private (page);
+
+    account_number = gsb_account_get_combo_account_number (priv->combo_bet_account);
+
+	if (gtk_toggle_button_get_active (button))
+	{
+		gsb_data_account_set_bet_credit_card (account_number, 1);
+	}
+	else
+	{
+		gchar *msg;
+
+		gsb_data_account_set_bet_credit_card (account_number, 0);
+		msg = g_strdup (_("Warning: You are about to delete this deferred debit card: \"%s\"\n"
+						  "Are you sure?"));;
+		if (dialogue_yes_no (msg, _("Confirmation of deletion of a deferred debit card"), GTK_RESPONSE_CANCEL))
+		{
+			bet_data_transfert_remove_line_from_card (account_number);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_use_bet_module), FALSE);
+		}
+		else
+		{
+			gsb_data_account_set_bet_credit_card (account_number, 1);
+			g_signal_handlers_block_by_func (G_OBJECT (button),
+											 G_CALLBACK (prefs_page_bet_account_select_bank_card_toggle),
+											 page);
+			gtk_toggle_button_set_active (button, TRUE);
+			g_signal_handlers_unblock_by_func (G_OBJECT (button),
+											   G_CALLBACK (prefs_page_bet_account_select_bank_card_toggle),
+											   page);
+		}
+		g_free (msg);
+	}
+
+	gsb_data_account_set_bet_show_onglets (account_number);
+    prefs_page_bet_account_changed (priv->combo_bet_account, page);
+
+    if (gsb_gui_navigation_get_current_account () == account_number)
+        bet_data_select_bet_pages (account_number);
+}
+
+/**
+ * callback checkbutton_bet_hist_use_data_in_account
+ *
+ * \param toggle button
+ * \param page
+ *
+ * \return
+ **/
+static void prefs_page_bet_account_use_data_in_account_toggle (GtkToggleButton *button,
+															   PrefsPageBetAccount *page)
+{
+	GHashTable *transfert_list;
+	GHashTableIter iter;
+	gpointer key, value;
+	gint account_number;
+	gint number = 0;
+	PrefsPageBetAccountPrivate *priv;
+	TransfertData *std;
+
+	priv = prefs_page_bet_account_get_instance_private (page);
+	devel_debug_int (gtk_toggle_button_get_active (button));
+
+	account_number = gsb_account_get_combo_account_number (priv->combo_bet_account);
+	transfert_list = bet_data_transfert_get_list ();
+	g_hash_table_iter_init (&iter, transfert_list);
+
+	if (gtk_toggle_button_get_active (button))
+	{
+		while (g_hash_table_iter_next (&iter, &key, &value))
+		{
+			std = (TransfertData *) value;
+
+			if (std->main_account_number == account_number)
+			{
+				number++;
+				gsb_data_account_set_bet_hist_use_data_in_account (std->card_account_number, 1);
+				gtk_widget_show (priv->vbox_hist_main_account_use_data);
+			}
+		}
+		gsb_data_account_set_bet_hist_use_data_in_account (account_number, number);
+		prefs_page_bet_account_set_label_bet_hist_main_account_use_data (number, priv);
+	}
+	else
+	{
+		gsb_data_account_set_bet_hist_use_data_in_account (account_number, 0);
+		while (g_hash_table_iter_next (&iter, &key, &value))
+		{
+			std = (TransfertData *) value;
+
+			if (std->main_account_number == account_number)
+			{
+				gsb_data_account_set_bet_hist_use_data_in_account (std->card_account_number, 0);
+				gtk_widget_hide (priv->vbox_hist_main_account_use_data);
+			}
+		}
+	}
+
+	gsb_data_account_set_bet_show_onglets (account_number);
+	prefs_page_bet_account_changed (priv->combo_bet_account, page);
+
+    gsb_data_account_set_bet_maj (account_number, BET_MAJ_ALL);
+    bet_data_update_bet_module (account_number, -1);
+
+	if (gsb_gui_navigation_get_current_account () == account_number)
+		bet_data_select_bet_pages (account_number);
+}
+
 /**
  * callback called when changing the account from the combo
  * re-fill the page with the account data
@@ -459,6 +703,7 @@ static gboolean prefs_page_bet_account_changed (GtkWidget *combo,
     gint account_number;
     gint bet_use_budget;
     gint active;
+	gint number = 0;
 	KindAccount kind;
 	GrisbiWinEtat *w_etat;
 	PrefsPageBetAccountPrivate *priv;
@@ -476,6 +721,9 @@ static gboolean prefs_page_bet_account_changed (GtkWidget *combo,
     g_signal_handlers_block_by_func (G_OBJECT (priv->checkbutton_bet_credit_card),
 									 G_CALLBACK (prefs_page_bet_account_select_bank_card_toggle),
 									 page);
+    g_signal_handlers_block_by_func (G_OBJECT (priv->checkbutton_hist_main_account_use_data),
+									 G_CALLBACK (prefs_page_bet_account_use_data_in_account_toggle),
+									 page);
 
 	bet_use_budget = gsb_data_account_get_bet_use_budget (account_number);
     switch (bet_use_budget)		/* -1 = pas de module possible 0 = non utilisé 1 = utilisé */
@@ -499,25 +747,34 @@ static gboolean prefs_page_bet_account_changed (GtkWidget *combo,
             break;
     }
 
+	/* on cache les deux vbox pour l'aggregation des données historiques*/
+	gtk_widget_hide (priv->vbox_hist_card_account_use_data);
+	gtk_widget_hide (priv->vbox_hist_main_account_use_data);
+
 	kind = gsb_data_account_get_kind (account_number);
     switch (kind)
     {
 		case GSB_TYPE_BANK:
             gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook_bet_account), 0);
             prefs_page_bet_account_initialise_duration_widget (account_number, account_page);
-            prefs_page_bet_account_initialise_select_historical_data (account_number, account_page);
+            prefs_page_bet_account_initialise_select_hist_data (account_number, account_page);
+			gtk_widget_show (priv->vbox_hist_main_account_use_data);
+
+			/* init checkbutton_hist_main_account_use_data */
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_hist_main_account_use_data),
+										  gsb_data_account_get_bet_hist_use_data_in_account (account_number));
 			break;
 		case GSB_TYPE_CASH:
 			if (w_etat->bet_cash_account_option == 1)
 			{
 				gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook_bet_account), 0);
 				prefs_page_bet_account_initialise_duration_widget (account_number, account_page);
-				prefs_page_bet_account_initialise_select_historical_data (account_number, account_page);
+				prefs_page_bet_account_initialise_select_hist_data (account_number, account_page);
 			}
 			else
 			{
 				gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook_bet_account), 0);
-				prefs_page_bet_account_initialise_select_historical_data (account_number, account_page);
+				prefs_page_bet_account_initialise_select_hist_data (account_number, account_page);
 			}
 			break;
 		case GSB_TYPE_LIABILITIES:
@@ -526,12 +783,19 @@ static gboolean prefs_page_bet_account_changed (GtkWidget *combo,
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_bet_credit_card), active);
 			if (active)
 			{
+				/* affiche un label si données partagées dans le compte principal */
+				number = gsb_data_account_get_bet_hist_use_data_in_account (account_number);
+				if (number)
+				{
+					gtk_widget_show (priv->vbox_hist_card_account_use_data);
+				}
+
 				gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook_bet_account), 0);
 				if (w_etat->bet_cash_account_option == 1)
 				{
 					prefs_page_bet_account_initialise_duration_widget (account_number, account_page);
 				}
-				prefs_page_bet_account_initialise_select_historical_data (account_number, account_page);
+				prefs_page_bet_account_initialise_select_hist_data (account_number, account_page);
 			}
 			else
 			{
@@ -554,41 +818,13 @@ retour:
 	g_signal_handlers_unblock_by_func (G_OBJECT (priv->checkbutton_bet_credit_card),
 									   G_CALLBACK (prefs_page_bet_account_select_bank_card_toggle),
 									   page);
+	g_signal_handlers_unblock_by_func (G_OBJECT (priv->checkbutton_hist_main_account_use_data),
+									   G_CALLBACK (prefs_page_bet_account_use_data_in_account_toggle),
+									   page);
     /* return */
     return FALSE;
 }
 
-/**
- * callback checkbutton select_bank_card
- *
- * \param toggle button
- * \param page
- *
- * \return
- **/
-static void prefs_page_bet_account_select_bank_card_toggle (GtkToggleButton *button,
-															PrefsPageBetAccount *page)
-{
-    gint account_number;
-	PrefsPageBetAccountPrivate *priv;
-
-	devel_debug (NULL);
-	priv = prefs_page_bet_account_get_instance_private (page);
-
-    account_number = gsb_account_get_combo_account_number (priv->combo_bet_account);
-
-	if (gtk_toggle_button_get_active (button))
-		gsb_data_account_set_bet_credit_card (account_number, 1);
-	else
-		gsb_data_account_set_bet_credit_card (account_number, 0);
-
-	gsb_data_account_set_bet_show_onglets (account_number);
-    prefs_page_bet_account_changed (priv->combo_bet_account, page);
-
-    if (gsb_gui_navigation_get_current_account () == account_number)
-        bet_data_select_bet_pages (account_number);
-}
-
 /**
  * callback called when changing the account from the button
  *
@@ -697,21 +933,22 @@ static void prefs_page_bet_account_setup_account_page (PrefsPageBetAccount *page
 	/* set the data for the checkbutton "Option for cash accounts" */
 	g_object_set_data (G_OBJECT (account_page), "bet_credit_card_hbox", priv->hbox_bet_credit_card);
 	g_object_set_data (G_OBJECT (account_page), "Data_for_forecast", priv->hbox_forecast_data);
-	g_object_set_data (G_OBJECT (account_page), "Data_for_historical", priv->hbox_historical_data);
+	g_object_set_data (G_OBJECT (account_page), "Data_for_hist", priv->hbox_hist_data);
 	g_object_set_data (G_OBJECT (account_page), "Data_for_credit", priv->vbox_liabilities_account);
 
     /* Data for the forecast */
 	/* Calculation of duration */
     widget = utils_widget_get_duration_widget (SPP_ORIGIN_CONFIG);
     gtk_box_pack_start (GTK_BOX (priv->vbox_forecast_data), widget, FALSE, FALSE, 0);
+	gtk_box_reorder_child (GTK_BOX (priv->vbox_forecast_data), widget, 0);
 
     /* Select the labels of the list */
-    widget = prefs_page_bet_account_get_select_labels_widget ();
-    gtk_box_pack_start (GTK_BOX (priv->vbox_forecast_data), widget, FALSE, FALSE, 0);
+	prefs_page_bet_account_init_select_labels_widget (priv);
 
-    /* Sources of historical data */
+	/* Sources of historical data */
 	widget = utils_widget_origin_data_new (account_page, SPP_ORIGIN_CONFIG);
-	gtk_box_pack_start (GTK_BOX (priv->vbox_historical_data), widget, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (priv->vbox_hist_data), widget, FALSE, FALSE, 0);
+	gtk_box_reorder_child (GTK_BOX (priv->vbox_hist_data), widget, 0);
 
     /* Data for the account of type GSB_TYPE_LIABILITIES */
     gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook_bet_account), priv->vbox_liabilities_account, NULL);
@@ -719,7 +956,7 @@ static void prefs_page_bet_account_setup_account_page (PrefsPageBetAccount *page
 	/* Data for the credit */
 	gtk_notebook_set_scrollable (GTK_NOTEBOOK (priv->notebook_credit_data), TRUE);
 
-	priv->vbox_loan_data = GTK_WIDGET (prefs_widget_loan_new (NULL));
+	priv->vbox_loan_data = GTK_WIDGET (widget_loan_new (NULL));
 	g_object_set_data (G_OBJECT (account_page), "Data_for_credit", priv->vbox_loan_data);
 	label = gtk_label_new (_("Initial loan"));
 	utils_widget_set_padding (label, MARGIN_BOX, 0);
@@ -761,6 +998,12 @@ static void prefs_page_bet_account_setup_account_page (PrefsPageBetAccount *page
 					  "toggled",
 					  G_CALLBACK (prefs_page_bet_account_select_bank_card_toggle),
 					  page);
+
+	/* set the signal checkbutton_bet_hist_use_data_in_account */
+    g_signal_connect (G_OBJECT (priv->checkbutton_hist_main_account_use_data),
+					  "toggled",
+					  G_CALLBACK (prefs_page_bet_account_use_data_in_account_toggle),
+					  page);
 }
 
 /******************************************************************************/
@@ -783,7 +1026,7 @@ static void prefs_page_bet_account_class_init (PrefsPageBetAccountClass *klass)
 	G_OBJECT_CLASS (klass)->dispose = prefs_page_bet_account_dispose;
 
 	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass),
-												 "/org/gtk/grisbi/ui/prefs_page_bet_account.ui");
+												 "/org/gtk/grisbi/prefs/prefs_page_bet_account.ui");
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageBetAccount, vbox_bet_account);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageBetAccount, hbox_bet_select_account);
@@ -794,12 +1037,69 @@ static void prefs_page_bet_account_class_init (PrefsPageBetAccountClass *klass)
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageBetAccount, vbox_bank_cash_account);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageBetAccount, hbox_forecast_data);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageBetAccount, vbox_forecast_data);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageBetAccount, hbox_historical_data);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageBetAccount, vbox_historical_data);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageBetAccount, hbox_hist_data);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageBetAccount, vbox_hist_data);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageBetAccount, vbox_liabilities_account);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageBetAccount, vbox_credit_data);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageBetAccount, notebook_credit_data);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageBetAccount, vbox_loan_data);
+
+	/* set origin of forecast data */
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+												  PrefsPageBetAccount,
+												  radiobutton_source_transaction0);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+												  PrefsPageBetAccount,
+												  radiobutton_source_transaction1);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+												  PrefsPageBetAccount,
+												  radiobutton_source_transaction2);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+												  PrefsPageBetAccount,
+												  radiobutton_source_transaction3);
+
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+												  PrefsPageBetAccount,
+												  radiobutton_source_scheduled0);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+												  PrefsPageBetAccount,
+												  radiobutton_source_scheduled1);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+												  PrefsPageBetAccount,
+												  radiobutton_source_scheduled2);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+												  PrefsPageBetAccount,
+												  radiobutton_source_scheduled3);
+
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass)
+												  ,PrefsPageBetAccount,
+												  radiobutton_source_futur0);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+												  PrefsPageBetAccount,
+												  radiobutton_source_futur1);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+												  PrefsPageBetAccount,
+												  radiobutton_source_futur2);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass)
+												  ,PrefsPageBetAccount,
+												  radiobutton_source_futur3);
+
+	/* ajout pour gerer l'agregation des données dans le compte principal */
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+												  PrefsPageBetAccount,
+												  vbox_hist_card_account_use_data);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+												  PrefsPageBetAccount,
+												  label_hist_card_account_use_data);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+												  PrefsPageBetAccount,
+												  vbox_hist_main_account_use_data);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+												  PrefsPageBetAccount,
+												  checkbutton_hist_main_account_use_data);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+												  PrefsPageBetAccount,
+												  label_hist_main_account_use_data);
 }
 
 /******************************************************************************/
