@@ -440,7 +440,6 @@ static void prefs_page_display_form_create_buttons_table (PrefsPageDisplayForm *
 
 			priv->tab_list_buttons[current_element_number-4] = gtk_toggle_button_new_with_label (changed_string);
 			gtk_widget_set_size_request (priv->tab_list_buttons[current_element_number-4], button_width, -1);
-			utils_widget_set_padding (priv->tab_list_buttons[current_element_number-4], 2, 2);
 			gtk_widget_set_hexpand (priv->tab_list_buttons[current_element_number-4], TRUE);
 			gtk_widget_set_name (priv->tab_list_buttons[current_element_number-4], "list_config_buttons");
 			g_object_set_data (G_OBJECT (priv->tab_list_buttons[current_element_number-4]),
@@ -520,17 +519,13 @@ static gboolean prefs_page_display_form_add_column (GtkButton *button,
 													GtkWidget *tree_view)
 {
     gint nb_columns;
-    gint new_size;
 
     nb_columns = gsb_data_form_get_nb_columns ();
 
 	if (nb_columns == MAX_WIDTH)
 		return FALSE;
 
-    /* split by 2 the size of the current last column to add the new column */
-    new_size = gsb_data_form_get_width_column (nb_columns - 1) / 2;
-    gsb_data_form_set_width_column (nb_columns - 1, new_size);
-    gsb_data_form_set_width_column (nb_columns, new_size);
+    /* add the new column */
     gsb_data_form_set_nb_columns (nb_columns + 1);
 
 	/* show the new column */
@@ -595,19 +590,11 @@ static gboolean prefs_page_display_form_remove_column (GtkButton *button,
 		}
     }
 
-    /* change the size of the last column */
-    gsb_data_form_set_width_column (nb_columns - 1,
-									gsb_data_form_get_width_column (nb_columns)
-									+
-									gsb_data_form_get_width_column (nb_columns));
-    gsb_data_form_set_width_column (nb_columns, 0);
-
 	/* hide the new column */
 	gtk_tree_view_column_set_visible (gtk_tree_view_get_column (GTK_TREE_VIEW (tree_view),
 																nb_columns),
 									  FALSE);
 
-
 	/* update form and list */
 	prefs_page_display_form_update_form_list (tree_view, FALSE);
 
@@ -975,7 +962,7 @@ static void prefs_page_display_form_class_init (PrefsPageDisplayFormClass *klass
 	G_OBJECT_CLASS (klass)->dispose = prefs_page_display_form_dispose;
 
 	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass),
-												 "/org/gtk/grisbi/ui/prefs_page_display_form.ui");
+												 "/org/gtk/grisbi/prefs/prefs_page_display_form.ui");
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayForm, vbox_display_form);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayForm, grid_buttons_cols_rows);
