@@ -393,11 +393,14 @@ static gboolean prefs_page_fyear_button_associate_clicked (GtkWidget *button,
     while (list_tmp)
     {
 		gint transaction_number;
+		gint fyear_ope;
 
 		transaction_number = gsb_data_transaction_get_transaction_number (list_tmp -> data);
-		if (!gsb_data_transaction_get_financial_year_number (transaction_number))
+		fyear_ope = gsb_data_transaction_get_financial_year_number (transaction_number);
+		if (fyear_ope <= 0)
 		{
 			gint fyear_number;
+printf ("fyear_ope = %d transaction_number = %d\n", fyear_ope, transaction_number);
 
 			fyear_number = gsb_data_fyear_get_from_date (gsb_data_transaction_get_date (transaction_number));
 			if (fyear_number)
@@ -577,7 +580,7 @@ static void prefs_page_fyear_setup_tree_view (PrefsPageFyear *page,
 								G_TYPE_STRING,			/* FYEAR_NAME_COLUMN */
 								G_TYPE_STRING,			/* FYEAR_BEGIN_DATE_COLUMN */
 								G_TYPE_STRING,			/* FYEAR_END_DATE_COLUMN */
-								G_TYPE_STRING,			/* FYEAR_INVALID_COLUMN */
+								G_TYPE_STRING,			/* FYEAR_INVALID_COLUMN affiche une icone */
 								G_TYPE_INT,				/* FYEAR_NUMBER_COLUMN */
 								GDK_TYPE_RGBA);			/* FYEAR_ROW_COLOR */
 
@@ -602,7 +605,7 @@ static void prefs_page_fyear_setup_tree_view (PrefsPageFyear *page,
 		{
 			column = gtk_tree_view_column_new_with_attributes (title[i],
 															   gtk_cell_renderer_pixbuf_new (),
-															   "stock-id", i,
+															   "icon-name", i,
 															   "cell-background-rgba", FYEAR_ROW_COLOR,
 															   NULL);
 		}
@@ -797,7 +800,7 @@ static void prefs_page_fyear_class_init (PrefsPageFyearClass *klass)
 	G_OBJECT_CLASS (klass)->dispose = prefs_page_fyear_dispose;
 
 	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass),
-												 "/org/gtk/grisbi/ui/prefs_page_fyear.ui");
+												 "/org/gtk/grisbi/prefs/prefs_page_fyear.ui");
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFyear, vbox_fyear);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFyear, grid_fyear_details);
