@@ -613,8 +613,8 @@ static void prefs_page_reconcile_sort_setup_button_collapse_all (GtkWidget *butt
 	image = gtk_image_new_from_file (filename);
 	g_free (filename);
 
-	gtk_button_set_image (GTK_BUTTON (button), image);
 	gtk_button_set_always_show_image (GTK_BUTTON (button), TRUE);
+	gtk_button_set_image (GTK_BUTTON (button), image);
 	gtk_widget_set_sensitive (button, FALSE);
 	expand_number = 0;
 }
@@ -798,7 +798,7 @@ static void prefs_page_reconcile_sort_class_init (PrefsPageReconcileSortClass *k
 	G_OBJECT_CLASS (klass)->dispose = prefs_page_reconcile_sort_dispose;
 
 	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass),
-												 "/org/gtk/grisbi/ui/prefs_page_reconcile_sort.ui");
+												 "/org/gtk/grisbi/prefs/prefs_page_reconcile_sort.ui");
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageReconcileSort, vbox_reconcile_sort);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageReconcileSort, button_collapse_all);
