@@ -38,7 +38,9 @@
 #include "bet_data.h"
 #include "bet_data_finance.h"
 #include "bet_future.h"
+#ifdef HAVE_GOFFICE
 #include "bet_graph.h"
+#endif /* HAVE_GOFFICE */
 #include "bet_tab.h"
 #include "categories_onglet.h"
 #include "custom_list.h"
@@ -95,7 +97,6 @@
 
 /*START_EXTERN*/
 extern GtkTreeModel *	bank_list_model;
-extern GtkWidget *		detail_devise_compte;
 extern gint 			id_timeout;
 extern GSList *			orphan_child_transactions;
 extern gint 			scheduler_current_tree_view_width;
@@ -173,35 +174,39 @@ void init_variables (void)
     /* no bank in memory for now */
     gsb_bank_free_combo_list_model ();
 
-    run.mise_a_jour_liste_comptes_accueil = FALSE;
-    run.mise_a_jour_liste_echeances_manuelles_accueil = FALSE;
-    run.mise_a_jour_liste_echeances_auto_accueil = FALSE;
-    run.mise_a_jour_soldes_minimaux = FALSE;
-    run.mise_a_jour_fin_comptes_passifs = FALSE;
+	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
+    w_run->mise_a_jour_liste_comptes_accueil = FALSE;
+    w_run->mise_a_jour_liste_echeances_manuelles_accueil = FALSE;
+    w_run->mise_a_jour_liste_echeances_auto_accueil = FALSE;
+    w_run->mise_a_jour_soldes_minimaux = FALSE;
+    w_run->mise_a_jour_fin_comptes_passifs = FALSE;
 
     orphan_child_transactions = NULL;
 
-    etat.affichage_echeances = SCHEDULER_PERIODICITY_ONCE_VIEW;
-    etat.affichage_echeances_perso_nb_libre = 0;
-    etat.affichage_echeances_perso_j_m_a = PERIODICITY_DAYS;
-
-	/* raz variables of etat and w_etat */
+	/* raz variables of  w_etat */
 	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
-    if (etat.name_logo && strlen (etat.name_logo))
-        g_free (etat.name_logo);
-    etat.name_logo = NULL;
-    etat.utilise_logo = 1;
+    w_etat->affichage_echeances = SCHEDULER_PERIODICITY_ONCE_VIEW;
+    w_etat->affichage_echeances_perso_nb_libre = 0;
+    w_etat->affichage_echeances_perso_j_m_a = PERIODICITY_DAYS;
+
+	/* raz variables of etat */
+    if (w_etat->name_logo && strlen (w_etat->name_logo))
+        g_free (w_etat->name_logo);
+    w_etat->name_logo = NULL;
+    w_etat->utilise_logo = 1;
+
     gsb_select_icon_init_logo_variables ();
 
     w_etat->retient_affichage_par_compte = 0;
+	w_etat->use_icons_file_dir = FALSE;
 
     /* reconcile (etat) */
-    run.reconcile_account_number = -1;
-    g_free (run.reconcile_final_balance);
-    if (run.reconcile_new_date)
-        g_date_free (run.reconcile_new_date);
-    run.reconcile_final_balance = NULL;
-    run.reconcile_new_date = NULL;
+    w_run->reconcile_account_number = -1;
+    g_free (w_run->reconcile_final_balance);
+    if (w_run->reconcile_new_date)
+        g_date_free (w_run->reconcile_new_date);
+    w_run->reconcile_final_balance = NULL;
+    w_run->reconcile_new_date = NULL;
 
     gsb_transactions_list_set_current_tree_view_width (0);
 	gsb_scheduler_list_set_current_tree_view_width (0);
@@ -214,49 +219,38 @@ void init_variables (void)
     w_run->display_two_lines = 0;
     w_run->display_three_lines = 0;
 
-    etat.import_files_nb_days = 2;
-    etat.get_fyear_by_value_date = FALSE;
+    w_etat->import_files_nb_days = 2;
+    w_etat->get_fyear_by_value_date = FALSE;
 
     /* init default combofix values */
-    etat.combofix_mixed_sort = FALSE;
-    etat.combofix_case_sensitive = FALSE;
-    etat.combofix_force_payee = FALSE;
-    etat.combofix_force_category = FALSE;
-
-    /* mis à NULL prévient un plantage aléatoire dans
-     * gsb_currency_update_combobox_currency_list */
-    detail_devise_compte = NULL;
+    w_etat->combofix_mixed_sort = FALSE;
+    w_etat->combofix_case_sensitive = FALSE;
+    w_etat->combofix_force_payee = FALSE;
+    w_etat->combofix_force_category = FALSE;
 
     /* the main notebook is set to NULL,
      * important because it's the checked variable in a new file
      * to know if the widgets are created or not */
     grisbi_win_free_general_notebook ();
 
+	/* free account_property_page */
+	grisbi_win_free_account_property_page ();
+
     /* defaut value for width and align of columns */
     gsb_transactions_list_init_tab_align_col_treeview (NULL);
     gsb_transactions_list_init_tab_width_col_treeview (NULL);
     gsb_scheduler_list_init_tab_width_col_treeview (NULL);
 
-    if (etat.transaction_column_width && strlen (etat.transaction_column_width))
-    {
-        g_free (etat.transaction_column_width);
-        etat.transaction_column_width = NULL;
-   }
-    if (etat.scheduler_column_width && strlen (etat.scheduler_column_width))
-    {
-        g_free (etat.scheduler_column_width);
-        etat.scheduler_column_width = NULL;
-   }
-
     gsb_gui_navigation_init_tree_view ();
 
     /* free the form */
     gsb_form_widget_free_list ();
     gsb_form_scheduler_free_list ();
+	gsb_date_free_last_date ();		/* fix crash bug 2236 */
 
-    /* divers */
-	etat.affichage_commentaire_echeancier = 0;	/* RAZ option utile si chargement d'un deuxième fichier */
-    etat.get_fyear_by_value_date = 0;           /* By default use transaction-date */
+		/* divers */
+	w_etat->affichage_commentaire_echeancier = 0;	/* RAZ option utile si chargement d'un deuxième fichier */
+    w_etat->get_fyear_by_value_date = 0;           /* By default use transaction-date */
 
     /* remove the timeout if necessary */
     if (id_timeout)
@@ -267,10 +261,10 @@ void init_variables (void)
 
     /* initializes the variables for the estimate balance module */
     /* création de la liste des données à utiliser dans le tableau de résultats */
-    bet_data_init_variables ();
+    bet_data_variables_init ();
     /* initialisation des boites de dialogue */
     bet_future_initialise_dialog (TRUE);
-    etat.bet_debut_period = 1;
+    w_etat->bet_debut_period = 1;
     /* defaut value for width of columns */
     bet_array_init_largeur_col_treeview (NULL);
 
@@ -278,7 +272,7 @@ void init_variables (void)
 	bet_data_loan_delete_all_loans ();
 
 #ifdef HAVE_GOFFICE
-    bet_graph_set_configuration_variables (NULL);
+    bet_graph_set_options_variables (NULL);
 #endif /* HAVE_GOFFICE */
 
 }
@@ -289,7 +283,10 @@ void init_variables (void)
  * */
 void free_variables (void)
 {
+	GrisbiWinEtat *w_etat;
+
 	devel_debug (NULL);
+	w_etat = grisbi_win_get_w_etat ();
 
 	/* free functions */
     gsb_data_archive_init_variables ();
@@ -328,29 +325,33 @@ void free_variables (void)
     gsb_form_widget_free_list_without_widgets ();
     gsb_form_scheduler_free_list ();
 
+	/* variables generales */
+	if (w_etat->accounting_entity)
+		g_free (w_etat->accounting_entity);
+	if (w_etat->adr_common)
+		g_free (w_etat->adr_common);
+	if (w_etat->adr_secondary)
+		g_free (w_etat->adr_secondary);
+	if (w_etat->date_format)
+		g_free (w_etat->date_format);
+
 	/* reset csv separator */
 	gsb_csv_export_set_csv_separator (NULL);
-	if (etat.csv_separator)
-		g_free (etat.csv_separator);
+	if (w_etat->csv_separator)
+		g_free (w_etat->csv_separator);
 
-	/* raz variables of etat and w_etat */
-	if (etat.name_logo && strlen (etat.name_logo))
-		g_free (etat.name_logo);
+	/* raz variables of etat */
+	if (w_etat->name_logo && strlen (w_etat->name_logo))
+		g_free (w_etat->name_logo);
 
-    /* reconcile (etat) */
-	if (run.reconcile_final_balance)
-	    g_free (run.reconcile_final_balance);
-    if (run.reconcile_new_date)
-        g_date_free (run.reconcile_new_date);
-
-    /* initializes the variables for the estimate balance module */
-    bet_data_free_variables ();
+    /* free the variables for the estimate balance module */
+    bet_data_variables_free ();
     bet_future_initialise_dialog (FALSE);
     bet_array_init_largeur_col_treeview (NULL);
 	bet_data_loan_delete_all_loans ();
 
 #ifdef HAVE_GOFFICE
-    bet_graph_free_configuration_variables ();
+    bet_graph_free_options_variables ();
 #endif /* HAVE_GOFFICE */
 }
 
