@@ -38,7 +38,6 @@
 
 /*START_INCLUDE*/
 #include "widget_bank_details.h"
-#include "gsb_account_property.h"
 #include "gsb_autofunc.h"
 #include "gsb_bank.h"
 #include "gsb_data_bank.h"
@@ -46,6 +45,7 @@
 #include "utils.h"
 #include "utils_editables.h"
 #include "utils_prefs.h"
+#include "widget_account_property.h"
 #include "erreur.h"
 
 /*END_INCLUDE*/
@@ -96,7 +96,7 @@ static void widget_bank_details_bic_code_changed (GtkEntry *entry,
     gint bank_number;
 
     bank_number = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (entry), "number_for_func"));
-    gsb_account_property_set_label_code_bic (bank_number);
+    widget_account_property_update_bank_data (bank_number);
 }
 
 /**
@@ -114,7 +114,7 @@ static void widget_bank_details_code_changed (GtkEntry *entry,
     gint bank_number;
 
     bank_number = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (entry), "number_for_func"));
-    gsb_account_property_set_label_code_banque (bank_number);
+    widget_account_property_update_bank_data (bank_number);
 }
 
 /**
@@ -148,7 +148,7 @@ static void widget_bank_details_setup_widget (WidgetBankDetails *w_bank_details,
         priv->entry_bank_name = gsb_autofunc_entry_new (NULL, NULL, NULL, NULL, 0);
         priv->entry_bank_code = gsb_autofunc_entry_new (NULL, NULL, NULL, NULL, 0);
         priv->entry_bank_BIC = gsb_autofunc_entry_new (NULL, NULL, NULL, NULL, 0);
-        priv->textview_bank_adr = gsb_autofunc_textview_new (NULL, NULL, NULL, NULL, 0);
+        gsb_autofunc_textview_new_from_ui (priv->textview_bank_adr, NULL, NULL, NULL, 0);
         priv->entry_bank_tel = gsb_autofunc_entry_new (NULL, NULL, NULL, NULL, 0);
         priv->entry_bank_mail = gsb_autofunc_entry_new (NULL, NULL, NULL, NULL, 0);
         priv->entry_bank_web = gsb_autofunc_entry_new (NULL, NULL, NULL, NULL, 0);
@@ -170,11 +170,11 @@ static void widget_bank_details_setup_widget (WidgetBankDetails *w_bank_details,
 													   NULL,
                        							 	   G_CALLBACK (gsb_data_bank_set_bic),
 													   0);
-        priv->textview_bank_adr = gsb_autofunc_textview_new (NULL,
-															 NULL,
-															 NULL,
-															 G_CALLBACK (gsb_data_bank_set_bank_address),
-															 0);
+		gsb_autofunc_textview_new_from_ui (priv->textview_bank_adr,
+											NULL,
+											NULL,
+											G_CALLBACK (gsb_data_bank_set_bank_address),
+											0);
 		priv->entry_bank_tel = gsb_autofunc_entry_new (NULL,
 													   NULL,
                         							   NULL,
@@ -205,9 +205,6 @@ static void widget_bank_details_setup_widget (WidgetBankDetails *w_bank_details,
     gtk_size_group_add_widget (size_group, priv->entry_bank_BIC);
     gtk_grid_attach (GTK_GRID (priv->grid_bank_details), priv->entry_bank_BIC, 2, 3, 2, 1);
 
-    gtk_size_group_add_widget (size_group, priv->textview_bank_adr);
-    gtk_grid_attach (GTK_GRID (priv->grid_bank_details), priv->textview_bank_adr, 2, 4, 2, 1);
-
     gtk_size_group_add_widget (size_group, priv->entry_bank_tel);
     gtk_grid_attach (GTK_GRID (priv->grid_bank_details), priv->entry_bank_tel, 2, 5, 2, 1);
 
@@ -272,23 +269,19 @@ static void widget_bank_details_setup_widget (WidgetBankDetails *w_bank_details,
 	/* set Notes */
     if (combobox)
     {
-        priv->textview_bank_notes = gsb_autofunc_textview_new (NULL, NULL, NULL, NULL, 0);
+		gsb_autofunc_textview_new_from_ui (priv->textview_bank_notes, NULL, NULL, NULL, 0);
     }
     else
     {
-        priv->textview_bank_notes = gsb_autofunc_textview_new (NULL,
-                        NULL,
-                        NULL,
-                        G_CALLBACK (gsb_data_bank_set_bank_note),
-                        0);
+		gsb_autofunc_textview_new_from_ui (priv->textview_bank_notes,
+										   NULL,
+										   NULL,
+										   G_CALLBACK (gsb_data_bank_set_bank_note),
+										   0);
     }
 
 	/* attach widget */
 	gtk_size_group_add_widget (size_group, priv->textview_bank_notes);
-    gtk_grid_attach (GTK_GRID (priv->grid_bank_details), priv->textview_bank_notes, 1, 14, 3, 1);
-
-	/* set width and heigh */
-	gtk_widget_set_size_request (priv->textview_bank_notes, -1, SW_MIN_HEIGHT);
 }
 
 /******************************************************************************/
@@ -334,6 +327,8 @@ static void widget_bank_details_class_init (WidgetBankDetailsClass *klass)
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), WidgetBankDetails, vbox_bank_details);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), WidgetBankDetails, grid_bank_details);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), WidgetBankDetails, textview_bank_adr);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), WidgetBankDetails, textview_bank_notes);
 }
 
 /******************************************************************************/
